@@ -59,26 +59,23 @@ struct tty {
 enum {
     // req(void)
     IFP_NONE = 0,
-    IFT_VOID_START,
-    IFP_FLUSH,
-    IFP_ZERO,
-    IFT_VOID_STOP,
+    IFT_void_min = 0x20,
+    IFT_void_max,
 
     // req(uint32_t)
-    IFT_INT_START = 0x40,
+    IFT_int_min = 0x40,
     IFP_ACTIVATE,
     IFP_DEACTIVATE,
     IFP_DEACTIVSES,
     IFP_REMOVE,
     IFP_GETINFO,
     IFP_GETINFO_T,
-    IFT_INT_STOP,
+    IFP_ZERO,
+    IFT_int_max,
 
     // req(const char *)
-    IFT_STR_START = 0x80,
-    IFT_STR_STOP,
-
-    NF_NEWLINE = 1 << 0,
+    IFT_str_min = 0x80,
+    IFT_str_max,
 };
 
 // infod.c
@@ -96,7 +93,7 @@ extern struct GOptmap_t GOpt;
 
 extern char *G_devname_nm(uint32_t, char *, size_t);
 extern char *G_devname_fs(uint32_t, char *, size_t);
-extern struct tty *get_tty(uint32_t);
+extern struct tty *get_tty(uint32_t, int);
 extern void log_close(struct tty *);
 extern void notify(int, const char *, ...);
 extern ssize_t send_wait(int, const void *, size_t, int);
