@@ -1,13 +1,13 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
-include/rpl_ioctl.h - IOCTL numbers for RPLD and RPLDEV
+include/rpl_ioctl.h - IOCTL numbers for RPLDEV
   Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
-  -- License restrictions apply (GPL2)
+  -- License restrictions apply (GPL v2)
 
   This file is part of ttyrpld.
   ttyrpld is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
-  the Free Software Foundation; however only version 2 of the License.
+  the Free Software Foundation; however ONLY version 2 of the License.
 
   ttyrpld is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,7 +19,7 @@ include/rpl_ioctl.h - IOCTL numbers for RPLD and RPLDEV
   Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA.
 
-  -- For details see doc/GPL2.txt.
+  -- For details see the COPYING file
 =============================================================================*/
 #ifndef RPL_IOCTL_H
 #define RPL_IOCTL_H 1
