@@ -43,18 +43,9 @@ kernel/rpldev.c - Kernel interface for RPLD
 #ifndef __user
 #    define __user
 #endif
-#if __GNUC__ == 3 && __GNUC_MINOR__ >= 4
-     /* GCC 3.4 requires functions-to-be-inlined to appear before the call
-     to those. Fleaky. Buggy? It's a GCC fault. It's not *my* duty to fix it.
-     At most to workaround. */
-#    define K_INLINE
-#else
-#    define K_INLINE inline
-#endif
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 0)
-// should also work for earlier than 2.4, it's just for the device number thing
-#    define KERNEL_2_4 1
+#    define KERNEL_2_4 1 // just for device number handling
 #endif
 
 #ifndef KBUILD_BASENAME
@@ -93,23 +84,23 @@ static unsigned int uif_poll(struct file *, poll_table *);
 static int uif_close(struct inode *, struct file *);
 
 // Local functions
-static K_INLINE ssize_t avail_R(void);
-static K_INLINE ssize_t avail_W(void);
-static K_INLINE unsigned int imin_uint(unsigned int, unsigned int);
-static K_INLINE void get_tty_devnr(uint32_t *, struct tty_struct *);
-static K_INLINE unsigned long mkdev_26(unsigned long, unsigned long);
+inline static ssize_t avail_R(void);
+inline static ssize_t avail_W(void);
+inline static unsigned int imin_uint(unsigned int, unsigned int);
+inline static void get_tty_devnr(uint32_t *, struct tty_struct *);
+inline static unsigned long mkdev_26(unsigned long, unsigned long);
 static int mv_buffer(struct rpld_packet *, const void *, size_t);
-static K_INLINE void mv_buffer2(const void *, size_t);
-static K_INLINE void mv_to_user(char __user *, size_t);
-static K_INLINE void my_swab(void *, size_t);
+inline static void mv_buffer2(const void *, size_t);
+inline static void mv_to_user(char __user *, size_t);
+inline static void my_swab(void *, size_t);
 
 // Variables
-static DECLARE_WAIT_QUEUE_HEAD(Inqueue);
+static DECLARE_WAIT_QUEUE_HEAD(Pull_queue);
 static DECLARE_MUTEX(Open_lock);
 static DECLARE_MUTEX(Buffer_lock);
 static char *Buffer = NULL, *BufRP = NULL, *BufWP = NULL;
-static size_t Bufsize = 32768; // each tty has 4096, and 32K might not suffice
-static int Minor_nr = MISC_DYNAMIC_MINOR, WOverrun = 0;
+static size_t Bufsize = 32768;
+static int Minor_nr = MISC_DYNAMIC_MINOR;
 static struct file_operations Fops = {
     .open    = uif_open,
     .read    = uif_read,
@@ -119,8 +110,11 @@ static struct file_operations Fops = {
     .release = uif_close,
     .owner   = THIS_MODULE,
 };
-static struct miscdevice Misc_info =
- {minor: MISC_DYNAMIC_MINOR, name: "rpl", fops: &Fops};
+static struct miscdevice Misc_info = {
+    .minor = MISC_DYNAMIC_MINOR,
+    .name  = "rpl",
+    .fops  = &Fops,
+};
 
 // Module info
 extern int __init init_module(void);
@@ -130,16 +124,13 @@ MODULE_AUTHOR("Jan Engelhardt <jengelh [at] linux01 gwdg de>");
 MODULE_LICENSE("GPL v2");
 MODULE_PARM_DESC(Bufsize, "Buffer size (default 32K)");
 MODULE_PARM_DESC(Minor_nr, "Minor number to use (default: DYNAMIC)");
-MODULE_PARM_DESC(WOverrun, "Display Buffer Overrun messages (default: off)");
 #ifdef KERNEL_2_4
 MODULE_PARM(Bufsize, "i");
 MODULE_PARM(Minor_nr, "i");
-MODULE_PARM(WOverrun, "i");
 EXPORT_NO_SYMBOLS;
 #else
 module_param(Bufsize, uint, S_IRUGO);
-module_param(Minor_nr, int, S_IRUSR);
-module_param(WOverrun, bool, S_IRUGO | S_IWUSR);
+module_param(Minor_nr, int, S_IRUGO);
 #endif
 
 //-----------------------------------------------------------------------------
@@ -189,7 +180,7 @@ static int krn_open(struct tty_struct *this, struct tty_struct *that) {
 }
 
 static int krn_read(const char __user *buf, size_t count,
-  struct tty_struct *tty)
+ struct tty_struct *tty)
 {
     /* The data flow is a bit weird at first. krn_read() gets the data on its
     way between ttyDriver(master) -> /dev/stdin(slave), meaning this function
@@ -207,7 +198,7 @@ static int krn_read(const char __user *buf, size_t count,
 }
 
 static int krn_write(const char __user *buf, size_t count,
-  struct tty_struct *tty)
+ struct tty_struct *tty)
 {
     // Data flow: /dev/stdout(slave) -> tty driver(master)
     /* Just as with krn_read() above, .dev2 is not set because it is not used
@@ -225,7 +216,7 @@ static int krn_write(const char __user *buf, size_t count,
 }
 
 static int krn_ioctl(struct tty_struct *tty, struct tty_struct *real_tty,
-  unsigned int cmd, unsigned long arg)
+ unsigned int cmd, unsigned long arg)
 {
     uint32_t cmd32;
     struct rpld_packet p;
@@ -295,13 +286,13 @@ static int uif_open(struct inode *inode, struct file *filp) {
 
     /* Update links. I do it here 'cause I do not want memory copying (from the
     tty driver to the buffer) when there is no one to read. */
-    rpl_qinit   = krn_init;
-    rpl_qopen   = krn_open;
-    rpl_qread   = krn_read;
-    rpl_qwrite  = krn_write;
-    rpl_qclose  = krn_close;
-    rpl_qioctl  = krn_ioctl;
-    rpl_qdeinit = krn_deinit;
+    rpl_qinit    = krn_init;
+    rpl_qopen    = krn_open;
+    rpl_qread    = krn_read;
+    rpl_qwrite   = krn_write;
+    rpl_qclose   = krn_close;
+    rpl_qioctl   = krn_ioctl;
+    rpl_qdeinit  = krn_deinit;
 
     /* The inode's times are changed as follows:
             Access Time: if data is read from the device
@@ -313,17 +304,17 @@ static int uif_open(struct inode *inode, struct file *filp) {
 }
 
 static ssize_t uif_read(struct file *filp, char __user *buf,
-  size_t count, loff_t *ppos)
+ size_t count, loff_t *ppos)
 {
     // Nothing read, nothing done
     if(count == 0) { return 0; }
 
     // Must sleep as long as there is no data
-    if(down_interruptible(&Buffer_lock)) { return -ERESTARTSYS; }
+    down(&Buffer_lock);
     while(BufRP == BufWP) {
         up(&Buffer_lock);
         if(filp->f_flags & O_NONBLOCK) { return -EAGAIN; }
-        if(wait_event_interruptible(Inqueue, (BufRP != BufWP))) {
+        if(wait_event_interruptible(Pull_queue, (BufRP != BufWP))) {
             return -ERESTARTSYS;
         }
         if(down_interruptible(&Buffer_lock)) { return -ERESTARTSYS; }
@@ -355,7 +346,7 @@ static loff_t uif_llseek(struct file *filp, loff_t offset, int origin) {
 }
 
 static int uif_ioctl(struct inode *inode, struct file *filp, unsigned int cmd,
-  unsigned long arg)
+ unsigned long arg)
 {
     if(_IOC_TYPE(cmd) != RPL_IOC_MAGIC) { return -ENOTTY; }
 
@@ -373,37 +364,37 @@ static int uif_ioctl(struct inode *inode, struct file *filp, unsigned int cmd,
 }
 
 static unsigned int uif_poll(struct file *filp, poll_table *wait) {
-    poll_wait(filp, &Inqueue, wait);
+    poll_wait(filp, &Pull_queue, wait);
     return POLLIN | POLLRDNORM;
 }
 
 static int uif_close(struct inode *inode, struct file *filp) {
-    rpl_qinit   = NULL;
-    rpl_qopen   = NULL;
-    rpl_qread   = NULL;
-    rpl_qwrite  = NULL;
-    rpl_qioctl  = NULL;
-    rpl_qclose  = NULL;
-    rpl_qdeinit = NULL;
+    rpl_qinit    = NULL;
+    rpl_qopen    = NULL;
+    rpl_qread    = NULL;
+    rpl_qwrite   = NULL;
+    rpl_qioctl   = NULL;
+    rpl_qclose   = NULL;
+    rpl_qdeinit  = NULL;
     vfree(Buffer);
     up(&Open_lock);
     return 0;
 }
 
 //-----------------------------------------------------------------------------
-static K_INLINE ssize_t avail_R(void) {
+inline static ssize_t avail_R(void) {
     // Return the number of available bytes to read
     if(BufWP >= BufRP) { return BufWP - BufRP; }
     return BufWP + Bufsize - BufRP;
 }
 
-static K_INLINE ssize_t avail_W(void) {
+inline static ssize_t avail_W(void) {
     // Return the number of available bytes to write
     if(BufWP >= BufRP) { return BufRP + Bufsize - BufWP - 1; }
     return BufRP - BufWP - 1;
 }
 
-static K_INLINE void get_tty_devnr(uint32_t *dev, struct tty_struct *tty) {
+inline static void get_tty_devnr(uint32_t *dev, struct tty_struct *tty) {
     // Get some unique number to identify the thing
 #ifdef KERNEL_2_4
     *dev = mkdev_26(MAJOR(tty->device), MINOR(tty->device));
@@ -413,11 +404,11 @@ static K_INLINE void get_tty_devnr(uint32_t *dev, struct tty_struct *tty) {
     return;
 }
 
-static K_INLINE unsigned int imin_uint(unsigned int a, unsigned int b) {
+inline static unsigned int imin_uint(unsigned int a, unsigned int b) {
     return a < b ? a : b;
 }
 
-static K_INLINE unsigned long mkdev_26(unsigned long maj, unsigned long min) {
+inline static unsigned long mkdev_26(unsigned long maj, unsigned long min) {
     return (maj << 20) | (min & 0xFFFFF);
 }
 
@@ -425,31 +416,20 @@ static int mv_buffer(struct rpld_packet *p, const void *buf, size_t count) {
     /* Copy the contents the tty driver received to our circulary buffer and
     also add a header (rpld_packet) to it so that the userspace daemon can
     recognize the type. */
-    static int has_overrun = 0;
-
     if(down_interruptible(&Buffer_lock)) { return -ERESTARTSYS; }
-
     if(avail_W() < sizeof(struct rpld_packet) + count) {
-        if(!has_overrun) {
-            if(WOverrun) {
-                printk(KERN_INFO PREFIX "mv_buffer(): Buffer overrun\n");
-            }
-            ++has_overrun;;
-        }
         up(&Buffer_lock);
         return -ENOSPC;
-    } else {
-        has_overrun = 0;
     }
 
     mv_buffer2(p, sizeof(struct rpld_packet));
     if(count > 0) { mv_buffer2(buf, count); }
     up(&Buffer_lock);
-    wake_up(&Inqueue);
+    wake_up(&Pull_queue);
     return count;
 }
 
-static K_INLINE void mv_buffer2(const void *src, size_t count) {
+inline static void mv_buffer2(const void *src, size_t count) {
     /* This function is responsible for copying (a specific amount of
     arbitrary data) into the circulary buffer. (Taking the wrappage into
     account!) The parent function -- mv_buffer() in this case -- must make sure
@@ -468,7 +448,7 @@ static K_INLINE void mv_buffer2(const void *src, size_t count) {
     return;
 }
 
-static K_INLINE void mv_to_user(char __user *dest, size_t count) {
+inline static void mv_to_user(char __user *dest, size_t count) {
     /* mv_to_user() reads COUNT bytes from the circulary buffer and puts it
     into userspace memory. */
     int x = Buffer + Bufsize - BufRP;
@@ -487,7 +467,7 @@ static K_INLINE void mv_to_user(char __user *dest, size_t count) {
     return;
 }
 
-static K_INLINE void my_swab(void *srcp, size_t count) {
+inline static void my_swab(void *srcp, size_t count) {
     if(count == 2) {
         uint16_t *ptr = srcp;
         *ptr = cpu_to_le16(*ptr);
