@@ -45,7 +45,7 @@ static void *client_thread(void *);
 static void set_session_status(uint32_t, int);
 static void getinfo_text(uint32_t, int);
 static void getinfo(uint32_t, int);
-static void zero_counters(void);
+static void zero_counters(uint32_t);
 
 inline static const char *basename_pp(const char *, const char *);
 static void block_signals(void);
@@ -99,24 +99,21 @@ static void *client_thread(void *arg) {
         static const uint32_t zero = 0;
         unsigned char req;
         uint32_t gint; // general int
-        char buf[4096];
+        //char buf[4096];
 
         if(!RECEIVE_FULL(fd, &req, sizeof(unsigned char)) || req == IFP_NONE) {
             break;
-        } else if(req > IFT_INT_START && req < IFT_INT_STOP) {
+        } else if(req > IFT_int_min && req < IFT_int_max) {
             if(!RECEIVE_FULL(fd, &gint, sizeof(uint32_t))) { break; }
             PP_swab(&gint, sizeof(uint32_t));
-        } else if(req > IFT_STR_START && req < IFT_STR_STOP) {
+        } /* else if(req > IFT_str_min && req < IFT_str_max) {
             if(!RECEIVE_FULL(fd, &gint, sizeof(uint32_t))) { break; }
             PP_swab(&gint, sizeof(uint32_t));
             if(!RECEIVE_FULL(fd, buf, min_uint(sizeof(buf), gint))) { break; }
-        }
+        } */
 
         switch(req) {
             // Voids
-            case IFP_ZERO:
-                zero_counters();
-                break;
 
             // Integers
             case IFP_ACTIVATE ... IFP_DEACTIVSES:
@@ -125,7 +122,7 @@ static void *client_thread(void *arg) {
             case IFP_REMOVE: {
                 struct tty *tty;
                 pthread_mutex_lock(&Ttys_lock);
-                if((tty = get_tty(gint)) != NULL) { log_close(tty); }
+                if((tty = get_tty(gint, 0)) != NULL) { log_close(tty); }
                 pthread_mutex_unlock(&Ttys_lock);
                 break;
             }
@@ -135,6 +132,9 @@ static void *client_thread(void *arg) {
             case IFP_GETINFO_T:
                 getinfo_text(gint, fd);
                 break;
+            case IFP_ZERO:
+                zero_counters(gint);
+                break;
 
             // Strings
             // currently none
@@ -165,7 +165,7 @@ static void getinfo_text(uint32_t dev, int fd) {
         skprintf(fd,
           "AC   DEVICE TTY      BYTES IN       OUT FILENAME\n"
           "==========================================================================\n"
-          "  [---,---] *       %9llu %9llu  ttyrpld " TTYRPLD_VERSION "\n"
+          "  [---,---] *       %9llu %9llu ttyrpld " TTYRPLD_VERSION "\n"
           "            IOCD: %zu/%zu/%zu/%zu  RW: %zu/%zu  I: %zu  B: %zu\n"
           "--------------------------------------------------------------------------\n",
           Stats.in, Stats.out, Stats.init, Stats.open, Stats.close,
@@ -182,7 +182,7 @@ static void getinfo_text(uint32_t dev, int fd) {
         HXbtrav_free(travp);
     } else {
         struct tty *tty;
-        if((tty = get_tty(dev)) == NULL) {
+        if((tty = get_tty(dev, 0)) == NULL) {
             pthread_mutex_unlock(&Ttys_lock);
             return;
         }
@@ -215,7 +215,7 @@ static void getinfo(uint32_t dev, int fd) {
         HXbtrav_free(travp);
     } else {
         struct tty *tty;
-        if((tty = get_tty(dev)) == NULL) {
+        if((tty = get_tty(dev, 0)) == NULL) {
             pthread_mutex_unlock(&Ttys_lock);
             return;
         }
@@ -230,7 +230,7 @@ static void set_session_status(uint32_t dev, int req) {
     struct tty *tty;
 
     pthread_mutex_lock(&Ttys_lock);
-    if((tty = get_tty(dev)) == NULL) {
+    if((tty = get_tty(dev, 1)) == NULL) {
         pthread_mutex_unlock(&Ttys_lock);
         return;
     }
@@ -240,23 +240,27 @@ static void set_session_status(uint32_t dev, int req) {
     return;
 }
 
-static void zero_counters(void) {
-    struct HXbtree_node *nd;
-    struct HXbtrav *travp;
-
+static void zero_counters(uint32_t dev) {
     pthread_mutex_lock(&Ttys_lock);
-    travp = HXbtrav_init(Ttys, NULL);
+    if(dev == 0) {
+        struct HXbtrav *travp = HXbtrav_init(Ttys, NULL);
+        struct HXbtree_node *nd;
 
-    while((nd = HXbtraverse(travp)) != NULL) {
-        struct tty *tty = nd->data;
+        while((nd = HXbtraverse(travp)) != NULL) {
+            struct tty *tty = nd->data;
+            tty->in = tty->out = 0;
+        }
+
+        memset(&Stats, 0, sizeof(Stats));
+        HXbtrav_free(travp);
+    } else {
+        struct tty *tty;
+        if((tty = get_tty(dev, 0)) == NULL) {
+            pthread_mutex_unlock(&Ttys_lock);
+            return;
+        }
         tty->in = tty->out = 0;
     }
-
-    Stats.open = Stats.close = Stats.read = \
-    Stats.write = Stats.ioctl = Stats.badpack = 0;
-    Stats.in = Stats.out = 0;
-
-    HXbtrav_free(travp);
     pthread_mutex_unlock(&Ttys_lock);
     return;
 }
@@ -264,6 +268,7 @@ static void zero_counters(void) {
 //-----------------------------------------------------------------------------
 inline static const char *basename_pp(const char *s, const char *t) {
     const char *p;
+    if(s == NULL) { return NULL; }
 
     if((p = strchr(t, '%')) != NULL) {
         if((p = HX_strbchr(t, p, '/')) != NULL) { return s + (p - t) + 1; }
