@@ -2,7 +2,7 @@
 ttyrpld - TTY replay daemon
 user/pctrl.c - "Remote control" for ttyreplay
   Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
-  -- License restrictions apply (GPL2)
+  -- License restrictions apply (GPL v2)
 
   This file is part of ttyrpld.
   ttyrpld is free software; you can redistribute it and/or modify it
@@ -19,7 +19,7 @@ user/pctrl.c - "Remote control" for ttyreplay
   Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA.
 
-  -- For details see doc/GPL2.txt.
+  -- For details see the COPYING file
 =============================================================================*/
 #include <sys/select.h>
 #include <sys/stat.h>
