@@ -172,12 +172,12 @@ char *G_devname_fs(uint32_t dev, char *buf, size_t count) {
     return buf;
 }
 
-struct tty *get_tty(uint32_t dev) {
+struct tty *get_tty(uint32_t dev, int create) {
     struct HXbtree_node *ts;
     struct tty *ret = NULL, *tty;
 
     if((ret = HXbtree_get(Ttys, (void *)dev)) != NULL) { return ret; }
-    if((tty = malloc(sizeof(struct tty))) == NULL) { return NULL; }
+    if(!create || (tty = malloc(sizeof(struct tty))) == NULL) { return NULL; }
 
     tty->dev    = dev;
     tty->uid    = -1;
