@@ -186,18 +186,19 @@ static int replay_file(int fd, const char *name) {
                 e_proc(fd, &packet, &ps, &tick, &stamp, &skew);
                 break;
             case EVT_IDENT:
-                fprintf(stderr, "\n" "Created using ");
+                fprintf(stderr, "\n\e[1;37m" "Created using ");
                 read_through(fd, STDERR_FILENO, packet.size);
-                fprintf(stderr, "\n");
+                fprintf(stderr, "\e[0m\n");
                 break;
             case EVT_DEINIT:
-                fprintf(stderr, "\n" "<tty device has been closed>\n");
+                fprintf(stderr, "\n\e[1;37;41m"
+                 "<tty device has been closed>\e[0m\n");
                 // fallthrough kinda
                 read_nullfm(fd, packet.size);
                 break;
             case EVT_READ:
                 if(ps.echo) {
-                    printf("\e[31m");
+                    printf("\e[1;37;41m");
                     e_proc(fd, &packet, &ps, &tick, &stamp, &skew);
                     printf("\e[0m");
                     break;
@@ -214,10 +215,11 @@ static int replay_file(int fd, const char *name) {
     pctrl_deactivate(0);
 
     if(eax < 0) {
-        perror("\n" "<Error while reading from stream>\n" "read():");
+        perror("\n\e[1;37;41m" "<Error while reading from stream>\e[0m\n"
+         "read():");
     }
 
-    printf("\n" "<Log replaying of %s finished>\n", name);
+    printf("\n\e[1;37;41m" "<Log replaying of %s finished>\e[0m\n", name);
     return ps.brk;
 }
 
