@@ -43,7 +43,7 @@ user/rplctl.c - INFOD client
 // Function prototypes
 static uint32_t getdev(const char *);
 static void send_int(int, unsigned char, uint32_t);
-static void send_void(int, unsigned char);
+//static void send_void(int, unsigned char);
 //static void send_string(int, unsigned char, const char *);
 static int unix_client(const char *);
 
@@ -105,7 +105,10 @@ static uint32_t getdev(const char *s) {
         while(*dirp != NULL) {
             char buf[MAXFNLEN];
             snprintf(buf, MAXFNLEN, "%s/%s", *dirp, s);
-            if(stat(buf, &sb) == 0) { ++found; break; }
+            if(stat(buf, &sb) == 0) {
+                ++found;
+                break;
+            }
             if(errno != ENOENT) {
                 fprintf(stderr, "Cannot stat %s: %s\n", buf, strerror(errno));
                 return 0;
@@ -158,13 +161,13 @@ static void send_int(int fd, unsigned char req, uint32_t dev) {
     return;
 }
 
+/*
 static void send_void(int fd, unsigned char req) {
     send_wait(fd, &req, sizeof(unsigned char), 0);
     read_reply(fd);
     return;
 }
 
-/*
 static void send_string(int fd, unsigned char req, const char *str) {
     size_t size = strlen(str);
     uint32_t szpack = size;
@@ -202,16 +205,14 @@ static int get_options(int *argc, const char ***argv) {
          "Capture data from tty", "tty"},
         {NULL, 'D', POPT_ARG_STRING, &tmp, 'D',
          "Ignore data from tty", "tty"},
-        {NULL, 'F', POPT_ARG_NONE, NULL, 'F',
-         "Flush tty table", NULL},
-        {NULL, 'L', POPT_ARG_NONE, NULL, 'L',
-         "Explicitly request info about all ttys", NULL},
+        {NULL, 'L', POPT_ARG_STRING | POPT_ARGFLAG_OPTIONAL, &tmp, 'L',
+         "Explicitly request info about all [one] ttys", "tty"},
         {NULL, 'S', POPT_ARG_STRING, &tmp, 'S',
          "Ignore data from tty until next tty session", "tty"},
         {NULL, 'X', POPT_ARG_STRING, &tmp, 'X',
          "Call log_close() for the given tty", "tty"},
-        {NULL, 'Z', POPT_ARG_NONE, NULL, 'Z',
-         "Zero all packet and byte counters", NULL},
+        {NULL, 'Z', POPT_ARG_STRING | POPT_ARGFLAG_OPTIONAL, &tmp, 'Z',
+         "Zero all packet and byte counters", "tty"},
         {NULL, 'f', POPT_ARG_STRING, &GOpt.infod_port, 0,
          "Path to the INFOD socket", "file"},
         {NULL, 't', POPT_ARG_NONE, &Opt.parseable, 0,
@@ -229,7 +230,6 @@ static int get_options(int *argc, const char ***argv) {
         static const int mapping[] = {
             ['A'] = IFP_ACTIVATE,
             ['D'] = IFP_DEACTIVATE,
-            ['F'] = IFP_FLUSH,
             ['S'] = IFP_DEACTIVSES,
             ['X'] = IFP_REMOVE,
             ['Z'] = IFP_ZERO,
@@ -247,15 +247,22 @@ static int get_options(int *argc, const char ***argv) {
                 free(tmp);
                 break;
             }
-            case 'F':
-            case 'Z':
+            case 'L': {
+                uint32_t dev = 0;
                 ++got;
-                send_void(Sockfd, mapping[c]);
+                if(tmp != NULL) { dev = getdev(tmp); }
+                send_int(Sockfd, IFP_GETINFO_A, dev);
+                free(tmp);
                 break;
-            case 'L':
+            }
+            case 'Z': {
+                uint32_t dev = 0;
                 ++got;
-                send_int(Sockfd, IFP_GETINFO_A, 0);
+                if(tmp != NULL) { dev = getdev(tmp); }
+                send_int(Sockfd, mapping[c], dev);
+                free(tmp);
                 break;
+            }
         }
     }
 
