@@ -197,7 +197,7 @@ static void mainloop(int fd) {
         }
 
         pthread_mutex_lock(&Ttys_lock);
-        if((tty = get_tty(packet.dev)) == NULL) {
+        if((tty = get_tty(packet.dev, 1)) == NULL) {
             G_skip(fd, packet.size, 0);
             pthread_mutex_unlock(&Ttys_lock);
             continue;
@@ -227,6 +227,27 @@ static int packet_preprox(struct mem_packet *packet) {
         [EVT_max]    = NULL,
     };
 
+    {
+        register long maj = K26_MAJOR(packet->dev);
+        if(maj == 128 /* Unix98 ptm (-) */) {
+            if(packet->event != EVT_DEINIT) {
+                /* All master side events (except EVT_DEINIT) are dropped,
+                since they are pty masters are an exact copy of their slaves,
+                so no need to record them too. */
+                return 0;
+            }
+
+            uint32_t tmp = packet->dev2;
+            packet->dev2 = packet->dev;
+            packet->dev  = tmp;
+        } else if(maj == 2 /* BSD ptm (/dev/ptypXY) */) {
+            /* Honestly, I am not sure whether BSD ptms also behave like Unix98
+            ptms above, but I assume it. So change major 2 to major 3. */
+            if(packet->event != EVT_DEINIT) { return 0; }
+            packet->dev = K26_MKDEV(K26_MAJOR(3), K26_MINOR(packet->dev));
+        }
+    }
+
     if(packet->event < EVT_max && tab[packet->event] != NULL) {
         ++*tab[packet->event];
     }
@@ -256,27 +277,6 @@ static int packet_preprox(struct mem_packet *packet) {
             return 0;
     }
 
-    {
-        register long maj = K26_MAJOR(packet->dev);
-        if(maj == 128 /* Unix98 ptm (-) */) {
-            if(packet->event != EVT_DEINIT) {
-                /* All master side events (except EVT_DEINIT) are dropped,
-                since they are pty masters are an exact copy of their slaves,
-                so no need to record them too. */
-                return 0;
-            }
-
-            uint32_t tmp = packet->dev2;
-            packet->dev2 = packet->dev;
-            packet->dev  = tmp;
-        } else if(maj == 2 /* BSD ptm (/dev/ptypXY) */) {
-            /* Honestly, I am not sure whether BSD ptms also behave like Unix98
-            ptms above, but I assume it. So change major 2 to major 3. */
-            if(packet->event != EVT_DEINIT) { return 0; }
-            packet->dev = K26_MKDEV(K26_MAJOR(3), K26_MINOR(packet->dev));
-        }
-    }
-
     return 1;
 }
 
@@ -589,10 +589,46 @@ static void sighandler_pipe(int s) {
 }
 
 //-----------------------------------------------------------------------------
+static void chkconf(void) {
+    /* Check whether the configuration file has been modified compared to the
+    original that was once installed. Exits with EXIT_FAILURE if modified.
+    `make install` will then NOT update it with the (possibly new)
+    configuration from the ttyrpld source tree. */
+    struct stat sb;
+    char buf[16];
+    FILE *fp;
+
+    if(stat("/etc/rpld.conf", &sb) != 0) {
+        if(errno == ENOENT) {
+            exit(EXIT_SUCCESS);
+        }
+        exit(EXIT_FAILURE);
+    }
+    if(sb.st_size == 0) {
+        exit(EXIT_SUCCESS);
+    }
+    if((fp = popen("md5sum /etc/rpld.conf", "r")) == NULL) {
+        exit(EXIT_FAILURE);
+    }
+    memset(buf, sizeof(buf), '\0');
+    if(fscanf(fp, "%16s", buf) != 1) {
+        exit(EXIT_FAILURE);
+    }
+    fclose(fp);
+    if(strncmp(buf, "d0b2b74655540c7c11fd872eaddaa862", 16) != 0) {
+        exit(EXIT_FAILURE);
+    }
+    exit(EXIT_SUCCESS);
+    return;
+}
+
 static int get_options(int *argc, const char ***argv) {
     static const char *_empty_argv[] = {NULL};
     char *tmp;
     struct poptOption options_table[] = {
+        {"chkconf", 0, POPT_ARG_NONE | POPT_ARGFLAG_DOC_HIDDEN, NULL,
+         0x100 | 'C', "Check whether the configuration file has been modified"
+         " (used by `make install` when updating)", NULL},
         {NULL, 'D', POPT_ARG_STRING, &Opt.ovdev, 0,
          "Path to the RPL device", "file"},
         {NULL, 'I', POPT_ARG_VAL, &Opt.infod_start, 1,
@@ -622,6 +658,9 @@ static int get_options(int *argc, const char ***argv) {
     ctx = poptGetContext(**argv, *argc, *argv, options_table, 0);
     while((c = poptGetNextOpt(ctx)) >= 0) {
         switch(c) {
+            case 0x100 | 'C':
+                chkconf();
+                break;
             case 'Q':
                 Opt.dolog = 0;
                 break;
